==> dde-launchpad_0.7.1.tar.xz: BUILD/translations/dde-launchpad_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>AnalysisView</name>
    <message>
        <source>No search results</source>
        <translation type="obsolete">Nenhum resultado</translation>
    </message>
</context>
<context>
    <name>AppItemMenu</name>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="31"/>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="41"/>
        <source>Pin to Top</source>
        <translation>Fixar no Topo</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="50"/>
        <source>Remove from favorites</source>
        <translation>Remover dos Favoritos</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="50"/>
        <source>Add to favorites</source>
        <translation>Adicionar aos Favoritos</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="64"/>
        <source>Send to desktop</source>
        <translation>Enviar para a área de trabalho</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="64"/>
        <source>Remove from desktop</source>
        <translation>Remover da Área de Trabalho</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="74"/>
        <source>Remove from dock</source>
        <translation>Remover da Dock</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="74"/>
        <source>Send to dock</source>
        <translation>Enviar para a dock</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="85"/>
        <source>Add to startup</source>
        <translation>Adicionar à inicialização</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="85"/>
        <source>Remove from startup</source>
        <translation>Remover da inicialização</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="92"/>
        <source>Use a proxy</source>
        <translation>Usar Proxy</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="100"/>
        <source>Disable display scaling</source>
        <translation>Desabilitar escala de exibição</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="107"/>
        <source>Uninstall</source>
        <translation>Desinstalar</translation>
    </message>
</context>
<context>
    <name>AppListView</name>
    <message>
        <source>Internet</source>
        <translation type="vanished">Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation type="vanished">Bate-Papo</translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="vanished">Player de Música</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">Player de Vídeo</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="vanished">Imagem</translation>
    </message>
    <message>
        <source>Office</source>
        <translation type="vanished">Escritório</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation type="vanished">Leitura</translation>
    </message>
    <message>
        <source>Development</source>
        <translation type="vanished">Desenvolvimento</translation>
    </message>
    <message>
        <source>System</source>
        <translation type="vanished">Sistema</translation>
    </message>
</context>
<context>
    <name>BottomBar</name>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="26"/>
        <source>Power</source>
        <translation>Energia</translation>
    </message>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="40"/>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
</context>
<context>
    <name>FrequentlyUsedView</name>
    <message>
        <location filename="../qml/windowed/FrequentlyUsedView.qml" line="29"/>
        <source>Frequently Used</source>
        <translation>Utilizado Frequentemente</translation>
    </message>
    <message>
        <location filename="../qml/windowed/FrequentlyUsedView.qml" line="29"/>
        <source>All Apps</source>
        <translation>Todos os Aplicativos</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <source>Search</source>
        <translation type="obsolete">Pesquisar</translation>
    </message>
</context>
<context>
    <name>LauncherController</name>
    <message>
        <location filename="../launchercontroller.cpp" line="19"/>
        <source>Show launcher (hidden by default)</source>
        <translation>Mostrar lançador (escondido por padrão)</translation>
    </message>
    <message>
        <location filename="../launchercontroller.cpp" line="20"/>
        <source>Toggle launcher visibility</source>
        <translation>Alternar visibilidade do lançador</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../qml/Main.qml" line="21"/>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="23"/>
        <source>Chat</source>
        <translation>Bate-Papo</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="25"/>
        <source>Music</source>
        <translation>Players de Música</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="27"/>
        <source>Video</source>
        <translation>Players de Vídeo</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="29"/>
        <source>Graphics</source>
        <translation>Imagem/Editores Gráficos</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="31"/>
        <source>Game</source>
        <translation>Jogos</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="33"/>
        <source>Office</source>
        <translation>Escritório</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="35"/>
        <source>Reading</source>
        <translation>Leitura</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="37"/>
        <source>Development</source>
        <translation>Desenvolvimento</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="39"/>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="41"/>
        <source>Others</source>
        <translation>Outros</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="313"/>
        <source>Are you sure you want to uninstall %1?</source>
        <translation>Tem certeza que quer desinstalar %1?</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="325"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="339"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
<context>
    <name>RecentlyInstalledView</name>
    <message>
        <location filename="../qml/windowed/RecentlyInstalledView.qml" line="27"/>
        <source>Recently Installed</source>
        <translation>Instalado Recentemente</translation>
    </message>
</context>
<context>
    <name>SearchResultView</name>
    <message>
        <location filename="../qml/windowed/SearchResultView.qml" line="26"/>
        <source>All Apps</source>
        <translation>Todos os Aplicativos</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SearchResultView.qml" line="76"/>
        <source>No search results</source>
        <translation>Nenhum resultado</translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="39"/>
        <source>Free sorting</source>
        <translation>Ordenação livre</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="52"/>
        <source>Sort by category</source>
        <translation>Ordenar por categoria</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="64"/>
        <source>Sort by name</source>
        <translation>Ordenar por nome</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="124"/>
        <source>Computer</source>
        <translation>Computador</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="139"/>
        <source>Pictures</source>
        <translation>Imagens</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="154"/>
        <source>Documents</source>
        <translation>Documentos</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="169"/>
        <source>Desktop</source>
        <translation>Área de Trabalho</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="184"/>
        <source>Control Center</source>
        <translation>Centro de Controle</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Categories</source>
        <translation type="vanished">Categorias</translation>
    </message>
    <message>
        <source>Power</source>
        <translation type="vanished">Energia</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="vanished">Configurações</translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="vanished">Pesquisar</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation type="vanished">Favoritos</translation>
    </message>
    <message>
        <source>Add your favorite apps here</source>
        <translation type="vanished">Adicione seus aplicativos favoritos aqui</translation>
    </message>
    <message>
        <source>All Apps</source>
        <translation type="vanished">Todos os Aplicativos</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation type="vanished">Nenhum resultado</translation>
    </message>
</context>
</TS>

==> dde-launchpad_0.8.5.tar.xz: BUILD/translations/dde-launchpad_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>AnalysisView</name>
    <message>
        <source>No search results</source>
        <translation type="obsolete">Nenhum resultado</translation>
    </message>
</context>
<context>
    <name>AppItemMenu</name>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="34"/>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="46"/>
        <source>Pin to Top</source>
        <translation>Fixar no topo</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="55"/>
        <source>Move to Top</source>
        <translation>Mover para o topo</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="65"/>
        <source>Remove from favorites</source>
        <translation>Remover dos favoritos</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="65"/>
        <source>Add to favorites</source>
        <translation>Adicionar aos favoritos</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="80"/>
        <source>Send to desktop</source>
        <translation>Enviar para área de trabalho</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="80"/>
        <source>Remove from desktop</source>
        <translation>Remover da área de trabalho</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="91"/>
        <source>Remove from dock</source>
        <translation>Remover do dock</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="91"/>
        <source>Send to dock</source>
        <translation>Fixar no dock</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="103"/>
        <source>Add to startup</source>
        <translation>Adicionar à inicialização</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="103"/>
        <source>Remove from startup</source>
        <translation>Remover da inicialização</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="111"/>
        <source>Use a proxy</source>
        <translation>Usar proxy</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="120"/>
        <source>Disable display scaling</source>
        <translation>Desativar escala de exibição</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="127"/>
        <source>Uninstall</source>
        <translation>Desinstalar</translation>
    </message>
</context>
<context>
    <name>AppListView</name>
    <message>
        <source>Internet</source>
        <translation type="vanished">Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation type="vanished">Bate-Papo</translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="vanished">Player de Música</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">Player de Vídeo</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="vanished">Imagem</translation>
    </message>
    <message>
        <source>Office</source>
        <translation type="vanished">Escritório</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation type="vanished">Leitura</translation>
    </message>
    <message>
        <source>Development</source>
        <translation type="vanished">Desenvolvimento</translation>
    </message>
    <message>
        <source>System</source>
        <translation type="vanished">Sistema</translation>
    </message>
</context>
<context>
    <name>BottomBar</name>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="32"/>
        <source>Power</source>
        <translation>Energia</translation>
    </message>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="56"/>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
</context>
<context>
    <name>FrequentlyUsedView</name>
    <message>
        <location filename="../qml/windowed/FrequentlyUsedView.qml" line="35"/>
        <source>Frequently Used</source>
        <translation>Usado frequentemente</translation>
    </message>
    <message>
        <source>All Apps</source>
        <translation type="vanished">Todos os Aplicativos</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <source>Search</source>
        <translation type="obsolete">Pesquisar</translation>
    </message>
</context>
<context>
    <name>LauncherController</name>
    <message>
        <location filename="../launchercontroller.cpp" line="19"/>
        <source>Show launcher (hidden by default)</source>
        <translation>Exibir lançador (oculto por padrão)</translation>
    </message>
    <message>
        <location filename="../launchercontroller.cpp" line="20"/>
        <source>Toggle launcher visibility</source>
        <translation>Alternar visibilidade do lançador</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../qml/Main.qml" line="22"/>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="24"/>
        <source>Chat</source>
        <translation>Comunicação</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="26"/>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="28"/>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="30"/>
        <source>Graphics</source>
        <translation>Imagem</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="32"/>
        <source>Game</source>
        <translation>Jogos</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="34"/>
        <source>Office</source>
        <translation>Produtividade</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="36"/>
        <source>Reading</source>
        <translation>Leitura</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="38"/>
        <source>Development</source>
        <translation>Desenvolvimento</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="40"/>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="42"/>
        <source>Others</source>
        <translation>Outros</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="398"/>
        <source>Are you sure you want to uninstall %1?</source>
        <translation>Desinstalar %1?</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="410"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="424"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
<context>
    <name>RecentlyInstalledView</name>
    <message>
        <location filename="../qml/windowed/RecentlyInstalledView.qml" line="34"/>
        <source>Recently Installed</source>
        <translation>Instalado recentemente</translation>
    </message>
</context>
<context>
    <name>SearchResultView</name>
    <message>
        <location filename="../qml/windowed/SearchResultView.qml" line="37"/>
        <source>All Apps</source>
        <translation>Todos os aplicativos</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SearchResultView.qml" line="102"/>
        <source>No search results</source>
        <translation>Nenhum resultado encontrado</translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="40"/>
        <source>Free sorting</source>
        <translation>Classificação livre</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="54"/>
        <source>Sort by category</source>
        <translation>Classificar por categoria</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="66"/>
        <source>Sort by name</source>
        <translation>Classificar por nome</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="142"/>
        <source>Computer</source>
        <translation>Computador</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="153"/>
        <source>Pictures</source>
        <translation>Imagens</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="164"/>
        <source>Documents</source>
        <translation>Documentos</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="175"/>
        <source>Desktop</source>
        <translation>Área de Trabalho</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="186"/>
        <source>Control Center</source>
        <translation>Central de Controle</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Categories</source>
        <translation type="vanished">Categorias</translation>
    </message>
    <message>
        <source>Power</source>
        <translation type="vanished">Energia</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="vanished">Configurações</translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="vanished">Pesquisar</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation type="vanished">Favoritos</translation>
    </message>
    <message>
        <source>Add your favorite apps here</source>
        <translation type="vanished">Adicione seus aplicativos favoritos aqui</translation>
    </message>
    <message>
        <source>All Apps</source>
        <translation type="vanished">Todos os Aplicativos</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation type="vanished">Nenhum resultado</translation>
    </message>
</context>
</TS>
